@@ -24,7 +24,6 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "mtools.h"
 #include "vfat.h"
 #include "nameclash.h"
@@ -36,7 +35,7 @@
 /**
  * Converts input to shortname
  * @param un unix name (in Unix charset)
- * 
+ *
  * @return 1 if name had to be mangled
  */
 static __inline__ int convert_to_shortname(doscp_t *cp, ClashHandling_t *ch,
@@ -70,7 +69,7 @@ static __inline__ int ask_rename(doscp_t *cp, ClashHandling_t *ch,
 {
 	int mangled;
 
-	/* TODO: Would be nice to suggest "autorenamed" version of name, press 
+	/* TODO: Would be nice to suggest "autorenamed" version of name, press
 	 * <Return> to get it.
 	 */
 #if 0
@@ -92,7 +91,7 @@ static __inline__ int ask_rename(doscp_t *cp, ClashHandling_t *ch,
 		if (isprimary)
 			strcpy(longname, tname);
 		else
-			mangled = convert_to_shortname(cp, 
+			mangled = convert_to_shortname(cp,
 						       ch, tname, shortname);
 	} while (mangled & 1);
 	return 1;
@@ -107,7 +106,7 @@ static __inline__ int ask_rename(doscp_t *cp, ClashHandling_t *ch,
 static __inline__ clash_action ask_namematch(doscp_t *cp,
 					     dos_name_t *dosname,
 					     char *longname,
-					     int isprimary, 
+					     int isprimary,
 					     ClashHandling_t *ch,
 					     int no_overwrite,
 					     int reason)
@@ -178,7 +177,7 @@ static __inline__ clash_action ask_namematch(doscp_t *cp,
 		fflush(opentty(1));
 		if (mtools_raw_tty) {
 			int rep;
-			rep = fgetc(opentty(1));			
+			rep = fgetc(opentty(1));
 			fputs("\n", stderr);
 			if(rep == EOF)
 				ans[0] = 'q';
@@ -336,7 +335,7 @@ static int is_reserved(char *ans, int islong)
 		    ((islong && !ans[4]) ||
 		     (!islong && !strncmp(ans+4,"    ",4))))
 			return 1;
-	
+
 	return 0;
 }
 
@@ -388,18 +387,18 @@ static __inline__ clash_action get_slots(Stream_t *Dir,
 					ch->use_longname)) {
 			case -1:
 				return NAMEMATCH_ERROR;
-				
+
 			case 0:
 				return NAMEMATCH_SKIP;
 				/* Single-file error error or skip request */
-				
+
 			case 5:
 				return NAMEMATCH_GREW;
 				/* Grew directory, try again */
-				
+
 			case 6:
 				return NAMEMATCH_SUCCESS; /* Success */
-		}	
+		}
 		match_pos = -2;
 		if (ssp->longmatch > -1) {
 			/* Primary Long Name Match */
@@ -407,7 +406,7 @@ static __inline__ clash_action get_slots(Stream_t *Dir,
 			fprintf(stderr,
 				"Got longmatch=%d for name %s.\n",
 				longmatch, longname);
-#endif			
+#endif
 			match_pos = ssp->longmatch;
 			isprimary = 1;
 		} else if ((ch->use_longname & 1) && (ssp->shortmatch != -1)) {
@@ -443,7 +442,7 @@ static __inline__ clash_action get_slots(Stream_t *Dir,
 	}
 	ret = process_namematch(cp, dosname, longname,
 				isprimary, ch, no_overwrite, reason);
-	
+
 	if (ret == NAMEMATCH_OVERWRITE && match_pos > -1){
 		if((entry.dir.attr & 0x5) &&
 		   (ask_confirmation("file is read only, overwrite anyway (y/n) ? ")))
@@ -451,7 +450,7 @@ static __inline__ clash_action get_slots(Stream_t *Dir,
 		/* Free up the file to be overwritten */
 		if(fatFreeWithDirentry(&entry))
 			return NAMEMATCH_ERROR;
-		
+
 #if 0
 		if(isprimary &&
 		   match_pos - ssp->match_free + 1 >= ssp->size_needed){
@@ -591,7 +590,7 @@ static int _mwrite_one(Stream_t *Dir,
 			case NAMEMATCH_ERROR:
 				return -1;	/* Non-file-specific error,
 						 * quit */
-				
+
 			case NAMEMATCH_SKIP:
 				return -1;	/* Skip file (user request or
 						 * error) */
@@ -617,7 +616,7 @@ static int _mwrite_one(Stream_t *Dir,
 					return -1;
 				}
 				expanded = 1;
-				
+
 				if (dir_grow(Dir, scan.max_entry))
 					return -1;
 				continue;
@@ -677,14 +676,14 @@ void init_clash_handling(ClashHandling_t *ch)
 	ch->is_label = 0;
 }
 
-int handle_clash_options(ClashHandling_t *ch, char c)
+int handle_clash_options(ClashHandling_t *ch, int c)
 {
 	int isprimary;
 	if(isupper(c))
 		isprimary = 0;
 	else
 		isprimary = 1;
-	c = ch_tolower(c);
+	c = tolower(c);
 	switch(c) {
 		case 'o':
 			/* Overwrite if primary name matches */
