@@ -20,9 +20,7 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
 #include "mainloop.h"
-#include "vfat.h"
 #include "mtools.h"
 #include "nameclash.h"
 #include "file_name.h"
@@ -46,9 +44,9 @@ static void _label_name(doscp_t *cp, const char *filename, int verbose UNUSEDP,
 
 	have_lower = have_upper = 0;
 	for(i=0; i<len; i++){
-		if(islower(wbuffer[i]))
+		if(iswlower(wbuffer[i]))
 			have_lower = 1;
-		if(isupper(wbuffer[i]))
+		if(iswupper(wbuffer[i]))
 			have_upper = 1;
 		if(!preserve_case)
 			wbuffer[i] = ch_towupper(wbuffer[i]);
@@ -283,7 +281,7 @@ void mlabel(int argc, char **argv, int type UNUSEDP)
 	have_boot = 0;
 	if( (!show || newLabel[0]) || set_serial != SER_NONE) {
 		Fs = GetFs(RootDir);
-		have_boot = (force_read(Fs,boot.characters,0,sizeof(boot)) ==
+		have_boot = (force_pread(Fs,boot.characters,0,sizeof(boot)) ==
 			     sizeof(boot));
 	}
 
@@ -320,13 +318,13 @@ void mlabel(int argc, char **argv, int type UNUSEDP)
 	}
 
 	if(need_write_boot) {
-		force_write(Fs, (char *)&boot, 0, sizeof(boot));
+		force_pwrite(Fs, (char *)&boot, 0, sizeof(boot));
 		/* If this is fat 32, write backup boot sector too */
 		if(!WORD_S(fatlen)) {
 			int backupBoot = WORD_S(ext.fat32.backupBoot);
-			force_write(Fs, (char *)&boot,
-				    backupBoot * WORD_S(secsiz),
-				    sizeof(boot));
+			force_pwrite(Fs, (char *)&boot,
+				     backupBoot * WORD_S(secsiz),
+				     sizeof(boot));
 		}
 	}
 
