@@ -16,12 +16,12 @@
  */
 
 #include "sysincludes.h"
-#include "msdos.h"
+#include "mtools.h"
 
-const char *mversion="4.0.39";
+const char *mversion="4.0.40";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "April 10th, 2022";
+const char *mdate = "June 6th, 2022";
 
-const char *mformat_banner = "MTOO4039";
+const char *mformat_banner = "MTOO4040";
